[CRIU] [PATCH] proc-parse: Inotify files migh have no watchee assigned

Cyrill Gorcunov gorcunov at openvz.org
Wed Nov 28 09:12:29 EST 2012


Same as eventpoll -- we might have no watchee assigned
but only inotify descriptor created.

Signed-off-by: Cyrill Gorcunov <gorcunov at openvz.org>
---
 proc_parse.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/proc_parse.c b/proc_parse.c
index c075c03..e26639c 100644
--- a/proc_parse.c
+++ b/proc_parse.c
@@ -935,10 +935,10 @@ int parse_fdinfo(int fd, int type,
 	if (entry_met)
 		return 0;
 	/*
 	 * An eventpoll file may have no target fds set thus
 	 * resulting in no tfd: lines in proc. This is normal.
 	 */
-	if (type == FD_TYPES__EVENTPOLL)
+	if (type == FD_TYPES__EVENTPOLL || type == FD_TYPES__INOTIFY)
 		return 0;
 
 	pr_err("No records of type %d found in fdinfo file\n", type);
@@ -935,10 +935,10 @@ int parse_fdinfo(int fd, int type,
 		return 0;
 	/*
-	 * An eventpoll file may have no target fds set thus
+	 * An eventpoll/inotify file may have no target fds set thus
 	 * resulting in no tfd: lines in proc. This is normal.
 	 */
-- 
1.7.7.6



More information about the CRIU mailing list